#!/usr/bin/env slsh

% Copyright (C) 2007 Laurent Perez <laurent.perez@unicaen.fr>
% Released under the terms of the GNU GPL (version 2 or later)

% This S-Lang script print entries added to a log file on the root screen
% of a X11 session.

require ("xosd");
require ("inotify");
require ("select");

define filter (line)
{
   $1 = strchop (line, ':', 0) [[2:]];
   if (length ($1) > 1)
     {
	% No need to display all those ACPI messages
	if (is_substr ($1 [1], "ACPI") > 0)
	  return "";
	% No need to display gconfd messages
	else if (is_substr ($1 [0], "gconfd") > 0)
	  return "";
	else
	  return strjoin ($1 [[1:]], ":") [[1:]][[:-2]];
     }
   else return "";
}

define test_filter (log_file)
{
   variable fp, line;
   
   fp = fopen (log_file, "r");
   while (-1 != fgets (&line, fp))
     {
	$0 = filter (line);
	if (strlen ($0) > 0)
	  {	     
	     () = printf ("%s\n", line [[:-2]]);
	     () = printf ("%s\n", $0);
	     () = printf ("---\n");
	  }	
     }
   () = fclose (fp);
}

define osd_config (last_lines, persist)
{   
   variable osd;
   
   osd = xosd_create (last_lines);
   if (-1 == xosd_set_font (osd, "-urw-nimbus sans l-medium-r-normal--18-*-*-*-*-*-*-*"))
     message (xosd_error);
   if (-1 == xosd_set_colour (osd, "cornflower blue"))
     message (xosd_error);
   if (-1 == xosd_set_outline_colour (osd, "blue"))
     message (xosd_error);
   if (-1 == xosd_set_outline_offset (osd, 1))
     message (xosd_error);
   % if (-1 == xosd_set_shadow_offset (osd, 1))
   % message (xosd_error);
   if (-1 == xosd_set_pos (osd, XOSD_bottom))
     message (xosd_error);
   if (-1 == xosd_set_timeout (osd, persist))
     message (xosd_error);
   return osd;
}

define slsh_main ()
{   
   variable fd, fds, wd, last_lines, persist, log_file, osd, st, size, n, fp, line, buf;
   
   log_file = __argv [1]; % file to monitor
   last_lines = 5; % number of lines to print
   persist = 10; % time to persist on screen (in seconds)

   osd = osd_config (last_lines, persist);
   
   st = stat_file (log_file);
   size = st.st_size;

   fd = inotify_init ();
   wd = inotify_add_watch (fd, log_file, IN_MODIFY);

   n = 0;
   forever
     {
	fds = select ([fd], [NULL], [NULL], -1);
	() = read (fd, &buf, inotify_pending (fd));
	st = stat_file (log_file);
	try
	  {	     
	     fp = fopen (log_file, "r");
	     if (fp == NULL) 
	       throw OpenError;
	     () = fseek (fp, size, SEEK_SET);
	     while (-1 != fgets (&line, fp))
	       {	    	     
		  $0 = filter (line);
		  if (strlen ($0) > 0)
		    {
		       if (n > 0)
			 () = xosd_scroll (osd, 1);
		       () = xosd_print (osd, last_lines - 1, $0);
		       n += 1;
		    }	     
	       }
	     () = fclose (fp);
	  }	
	catch OpenError:
	  {
	     () = xosd_print (osd, last_lines - 1, "Failed to open " + log_file);
	  }
	size = st.st_size;	
     }
}
