\function{inotify_init}
\synopsis{Initialize the inotify system}
\usage{FD_Type inotify_init ()}
\description
The \ifun{inotify_init} function initialize the inotify system.
\example
#v+
try (e)
   fd = inotify_init ()
catch InotifyError:
{
   message (e.descr);
}   
#v-
\notes
File descriptor returned by \ifun{inotify_init} may be closed by \ifun{close}
S-Lang function.
\done

\function{inotify_add_watch}
\synopsis{Add a watch}
\usage{Integer_Type inotify_add_watch (fd, path, mask)}
#v+
    FD_Type fd;
    String_Type path;
    UInteger_Type mask;
#v-
\description
The \ifun{inotify_add_watch} adds a watch for the one or more events
given by the bitmask \exmp{mask} on the file \exmp{path} to the inotify
instance associated with the file descriptor \exmp{fd}. If the function
fails, \exmp{-1} will be returned.
Valid events are :
      IN_ACCESS           File was read from.
      IN_MODIFY           File was written to.
      IN_ATTRIB           File's metadata (inode or xattr) was changed.
      IN_CLOSE_WRITE      File was closed (and was open for writing).
      IN_CLOSE_NOWRITE    File was closed (and was not open for writing).
      IN_OPEN             File was opened.
      IN_MOVED_FROM       File was moved away from watch.
      IN_MOVED_TO         File was moved to watch.
      IN_DELETE           File was deleted.
      IN_DELETE_SELF      The watch itself was deleted.
      IN_CLOSE            IN_CLOSE_WRITE | IN_CLOSE_NOWRITE
      IN_MOVE             IN_MOVED_FROM | IN_MOVED_TO
      IN_ALL_EVENTS       Bitwise OR of all events.
\seealso{inotify_rm_watch}
\done

\function{inotify_rm_watch}
\synopsis{Remove a watch}
\usage{Integer_Type inotify_rm_watch (FD_Type fd, Integer_Type wd)}
\description
This function removes the watch associated with the watch descriptor \exmp{wd}
from the inotify instance associated with the file descriptor \exmp{fd}.
If the function fails, \exmp{-1} will be returned.
\seealso{inotify_add_watch}
\done

\function{inotify_pending}
\synopsis{Return the size of the pending event queue}
\usage{Integer_Type inotify_pending (FD_Type fd)}
\description
The \ifun{inotify_pending} function return the size in bytes of the pending event
queue.
\done

\function{inotify_read_event}
\synopsis{Read next event in the event queue}
\usage{(wd, mask, cookie, name) = inotify_read_event (FD_Type fd)}
#v+
Integer_Type wd;
UInteger_Type mask;
UInteger_Type cookie;
String_Type name;
#v-
\description
The \ifun{inotify_read_event} function return informations about next
event in the event queue. \exmp{wd} is the watch descriptor originally
returned by \ifun{inotify_add_watch}. \exmp{mask} is a bitmask
representing the event that occurred. \exmp{cookie} is a unique
identifier linking together two related but separate events. \exmp{name}
contains the name of the object to which the event occurred,
relative to \exmp{wd}, if applicable.
\example
#v+
try (e)
   (wd, mask, cookie, name) = inotify_read_event (fd)
catch InotifyError:
{
   message (e.descr);
}   
#v-
\notes
In addition to the events listed earlier, following events are also
applicable :
      IN_UNMOUNT       The backing filesystem was unmounted.
      IN_Q_OVERFLOW    The inotify queue overflowed.
      IN_IGNORED       The watch was automatically removed, because the file was
                       deleted or its filesystem was unmounted.
\done
